@@ -20,13 +20,13 @@
 PsgpData prepareData(SEXP xData, SEXP yData, SEXP params, SEXP sensorMetadata, SEXP sensorIndices, bool paramsFromVario) {
 	// Input validation
 	if (xData == R_NilValue || yData == R_NilValue) {
-		Rf_error("xData and yData cannot be NULL");
+		Rcpp::stop("xData and yData cannot be NULL");
 	}
 	if (length(xData) != length(yData) * 2) {
-		Rf_error("xData length must be twice yData length (x,y coordinates for each observation)");
+		Rcpp::stop("xData length must be twice yData length (x,y coordinates for each observation)");
 	}
 	if (length(yData) <= 0) {
-		Rf_error("yData must contain at least one observation");
+		Rcpp::stop("yData must contain at least one observation");
 	}
 
 	PsgpData data;
@@ -132,14 +132,14 @@ SEXP predict(SEXP xData, SEXP yData, SEXP xPred, SEXP R_psgpParams, SEXP sensorI
 
 	// Prediction inputs and outputs - with input validation
 	if (xPred == R_NilValue || REAL(xPred) == NULL) {
-		Rf_error("xPred cannot be NULL");
+		Rcpp::stop("xPred cannot be NULL");
 	}
 	int xPredLen = length(xPred);
 	if (xPredLen % 2 != 0) {
-		Rf_error("xPred length must be even (x,y coordinate pairs)");
+		Rcpp::stop("xPred length must be even (x,y coordinate pairs)");
 	}
 	if (xPredLen <= 0) {
-		Rf_error("xPred must contain at least one coordinate pair");
+		Rcpp::stop("xPred must contain at least one coordinate pair");
 	}
 
 	int numPred = xPredLen / 2;
